import type { Either, ErrorResolver } from '@lokalise/node-core';
import type { QueueConsumer, NewQueueOptions, Deserializer, ExistingQueueOptions } from '@message-queue-toolkit/core';
import type { Message } from 'amqplib';
import type { AMQPConsumerDependencies, CreateAMQPQueueOptions } from './AbstractAmqpService';
import { AbstractAmqpService } from './AbstractAmqpService';
export type AMQPLocatorType = {
    queueName: string;
};
export type NewAMQPConsumerOptions<MessagePayloadType extends object> = NewQueueOptions<MessagePayloadType, CreateAMQPQueueOptions> & {
    deserializer?: Deserializer<MessagePayloadType, Message>;
};
export type ExistingAMQPConsumerOptions<MessagePayloadType extends object> = ExistingQueueOptions<MessagePayloadType, AMQPLocatorType> & {
    deserializer?: Deserializer<MessagePayloadType, Message>;
};
export declare abstract class AbstractAmqpConsumer<MessagePayloadType extends object> extends AbstractAmqpService<MessagePayloadType, AMQPConsumerDependencies> implements QueueConsumer {
    private readonly transactionObservabilityManager?;
    protected readonly errorResolver: ErrorResolver;
    private readonly deserializer;
    constructor(dependencies: AMQPConsumerDependencies, options: NewAMQPConsumerOptions<MessagePayloadType> | ExistingAMQPConsumerOptions<MessagePayloadType>);
    abstract processMessage(messagePayload: MessagePayloadType): Promise<Either<'retryLater', 'success'>>;
    private deserializeMessage;
    start(): Promise<void>;
}
